# Bento

Bento is a toolkit for ingesting, visualizing, and analyzing spatial transcriptomics data at subcellular resolution. 

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install bento.

```bash
pip install bento-tools
```

## Usage

```python
import bento
# Todo
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[MIT](https://choosealicense.com/licenses/mit/)